#[non_exhaustive]pub struct Unsized {
pub ordinal: Ordinal,
pub member: &'static str,
pub type_name: &'static str,
}Expand description
A payload with no size in the encoding a budget was asked for: its
EncodedSizes field for that encoding is None. The budget is not
computed, because a missing size is not estimated.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.ordinal: OrdinalThe member’s ordinal.
member: &'static strThe member’s name.
type_name: &'static strThe name of the payload type that has no size.