Interface

Trait Interface 

pub trait Interface {
    const CATALOG: &'static CatalogRef;
    const NUMBER: InterfaceNo;
    const PROVISIONAL: bool;
    const NAME: &'static str;
    const MEMBERS: &'static [Member];
}
An interface’s descriptor.

Required Associated Constants

const CATALOG: &'static CatalogRef

The catalog the interface belongs to.

const NUMBER: InterfaceNo

The interface number in that catalog.

const PROVISIONAL: bool

true when the number is provisional, not yet frozen in the lock file.

const NAME: &'static str

The interface name.

const MEMBERS: &'static [Member]

The members, in ordinal order. A reserved ordinal has no row, so the index of a row is not its ordinal minus one.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors