#[non_exhaustive]pub enum Transport {
Timeout,
Undelivered,
Down,
Corrupt,
Busy,
}Expand description
An infrastructure failure that the runtime detected, ridl 10.3.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Timeout
The response bound passed without a reply.
Undelivered
A command received no delivery acknowledgment within its bound.
Down
The connection to the peer is lost.
Corrupt
A payload is not a well-formed encoding.
Busy
The providing runtime refused the call at admission and the caller may
retry later. Crosses the frame as a response outcome (frame
specification 9.6).