WakeFlag

Struct WakeFlag 

pub struct WakeFlag(/* private fields */);
The read side of a flag_waker: whether the waker was woken since the last take.

Implementations

Source

impl WakeFlag

pub fn take(&self) -> bool

Return true if the waker was woken, by value or by reference, from any thread, since the flag was created or last taken, and clear the flag.