pub struct CatalogRef {
pub name: &'static str,
pub hash: CatalogHash,
}Expand description
A catalog: one package’s interfaces.
Two CatalogRefs are equal only when both the names and the hashes are
equal, because two packages with the same contents can have the same hash.
Fields
name: &'static strThe package name.
hash: CatalogHashThe catalog hash.